Struct Flags

pub struct Flags(/* private fields */);
Frame flags.

Implementations

Source

impl Flags

pub const fn empty() -> Self

Create a new set of frame flags with no flag set.

pub const fn from_bits(bits: u8) -> Self

Create a new set of frame flags from bits.

The upper 6 bits of bits are discarded.

pub const fn bits(self) -> u8

Get the bit representation of the flags.

pub const fn is_any_set(self, other: Self) -> bool

Check whether any flag in other is set in self.

If other contains only one flag, this method behaves identical to is_all_set().

pub const fn is_all_set(self, other: Self) -> bool

Check whether all flags in other are set in self.

If other contains only one flag, this method behaves identical to is_any_set().

pub fn set(&mut self, other: Self)

Set the flags of other in self.

pub fn set_if<F>(&mut self, other: Self, f: F)
where F: FnOnce() -> bool,

Set the flags of other in self if the predicate f returns true.

pub fn unset(&mut self, other: Self)

Unset the flags of other in self.

pub fn unset_if<F>(&mut self, other: Self, f: F)
where F: FnOnce() -> bool,

Unset the flags of other in self if the predicate f returns true.

pub fn set_or_unset(&mut self, other: Self, set: bool)

Set or unset the flags of other in self depending on set.

If set is true, this method will set the flags of other in self. If set is false, it will unset them.

pub fn set_or_unset_with<F>(&mut self, other: Self, f: F)
where F: FnOnce() -> bool,

Set or unset the flags of other in self based on a predicate f.