Struct Wants

pub struct Wants(/* private fields */);
Signal to the calling code that parsing cannot continue until this many more bytes have been read.

Implementations

Source

impl Wants

pub fn get(&self) -> usize

Get the number of bytes required before parsing can make progress.